Learn R Programming

dmri.tracking (version 0.1.0)

tractography: Tractography

Description

Visualize the result from v.track. r package rgl is required.

Usage

tractography(loc, vec)

Arguments

loc

Voxel coordinates that the reconstructed fiber go through

vec

Diffusion direction that used to reconstruct the fiber

Value

No return value. The reconstructed fiber is visualized on the opened rgl window.

References

R. K. W. Wong, T. C. M. Lee, D. Paul, J. Peng and for the Alzheimer's Disease Neuroimaging Initiative. (2016) "Fiber Direction Estimation, Smoothing and Tracking in Diffusion MRI". The Annals of Applied Statistics, 10(3), 1137-1156.

See Also

The tracking result from v.track can be used for tractography in dmri.tracking package.

Examples

Run this code
# NOT RUN {
#Load an example output from the peak detection algorithm
load(system.file("extdata", "peakresult.rda", package = "dmri.tracking"))

str(peak.result)  #Output from the peak detection algorithm

#Apply Tracking algorithm
result = v.track(v.obj = peak.result, max.line=500)


#Plot tracking result.
# }
# NOT RUN {
library(rgl)
open3d()
for (iind in (result$sorted.iinds[result$sorted.update.ind])){
  cat(iind,"\n")
  tractography(result$tracks1[[iind]]$inloc, result$tracks1[[iind]]$dir)
  tractography(result$tracks2[[iind]]$inloc, result$tracks2[[iind]]$dir)
}
# }
# NOT RUN {
#An example to prepare v.obj is available in https://github.com/vic-dragon/dmri.tracking

# }

Run the code above in your browser using DataLab